@@ -88,6 +88,13 @@ supermod.Items.subclass = ItemsSub
 # end class ItemsSub
 
 
+class itemSub(supermod.item):
+    def __init__(self, partNum=None, productName=None, quantity=None, USPrice=None, comment=None, shipDate=None):
+        super(itemSub, self).__init__(partNum, productName, quantity, USPrice, comment, shipDate, )
+supermod.item.subclass = itemSub
+# end class itemSub
+
+
 class AddressSub(supermod.Address):
     def __init__(self, name=None, street=None, city=None, extensiontype_=None):
         super(AddressSub, self).__init__(name, street, city, extensiontype_, )
@@ -109,13 +116,6 @@ supermod.UKAddress.subclass = UKAddressSub
 # end class UKAddressSub
 
 
-class itemTypeSub(supermod.itemType):
-    def __init__(self, partNum=None, productName=None, quantity=None, USPrice=None, comment=None, shipDate=None):
-        super(itemTypeSub, self).__init__(partNum, productName, quantity, USPrice, comment, shipDate, )
-supermod.itemType.subclass = itemTypeSub
-# end class itemTypeSub
-
-
 def get_root_tag(node):
     tag = supermod.Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = None
@@ -125,7 +125,7 @@ def get_root_tag(node):
     return tag, rootClass
 
 
-def parse(inFilename):
+def parse(inFilename, silence=False):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
@@ -136,15 +136,16 @@ def parse(inFilename):
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
     doc = None
-    sys.stdout.write('<?xml version="1.0" ?>\n')
-    rootObj.export(
-        sys.stdout, 0, name_=rootTag,
-        namespacedef_='',
-        pretty_print=True)
+    if not silence:
+        sys.stdout.write('<?xml version="1.0" ?>\n')
+        rootObj.export(
+            sys.stdout, 0, name_=rootTag,
+            namespacedef_='xmlns:ipo="http://www.example.com/IPO"',
+            pretty_print=True)
     return rootObj
 
 
-def parseEtree(inFilename):
+def parseEtree(inFilename, silence=False):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
@@ -158,15 +159,16 @@ def parseEtree(inFilename):
     mapping = {}
     rootElement = rootObj.to_etree(None, name_=rootTag, mapping_=mapping)
     reverse_mapping = rootObj.gds_reverse_node_mapping(mapping)
-    content = etree_.tostring(
-        rootElement, pretty_print=True,
-        xml_declaration=True, encoding="utf-8")
-    sys.stdout.write(content)
-    sys.stdout.write('\n')
+    if not silence:
+        content = etree_.tostring(
+            rootElement, pretty_print=True,
+            xml_declaration=True, encoding="utf-8")
+        sys.stdout.write(content)
+        sys.stdout.write('\n')
     return rootObj, rootElement, mapping, reverse_mapping
 
 
-def parseString(inString):
+def parseString(inString, silence=False):
     from StringIO import StringIO
     doc = parsexml_(StringIO(inString))
     rootNode = doc.getroot()
@@ -178,14 +180,15 @@ def parseString(inString):
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
     doc = None
-    sys.stdout.write('<?xml version="1.0" ?>\n')
-    rootObj.export(
-        sys.stdout, 0, name_=rootTag,
-        namespacedef_='')
+    if not silence:
+        sys.stdout.write('<?xml version="1.0" ?>\n')
+        rootObj.export(
+            sys.stdout, 0, name_=rootTag,
+            namespacedef_='xmlns:ipo="http://www.example.com/IPO"')
     return rootObj
 
 
-def parseLiteral(inFilename):
+def parseLiteral(inFilename, silence=False):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     roots = get_root_tag(rootNode)
@@ -196,11 +199,12 @@ def parseLiteral(inFilename):
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
     doc = None
-    sys.stdout.write('#from ipo2_sup import *\n\n')
-    sys.stdout.write('import ipo2_sup as model_\n\n')
-    sys.stdout.write('rootObj = model_.purchaseOrder(\n')
-    rootObj.exportLiteral(sys.stdout, 0, name_="purchaseOrder")
-    sys.stdout.write(')\n')
+    if not silence:
+        sys.stdout.write('#from ipo2_sup import *\n\n')
+        sys.stdout.write('import ipo2_sup as model_\n\n')
+        sys.stdout.write('rootObj = model_.purchaseOrder(\n')
+        rootObj.exportLiteral(sys.stdout, 0, name_="purchaseOrder")
+        sys.stdout.write(')\n')
     return rootObj
 
 
