@@ -16,15 +16,16 @@ class GenTest(unittest.TestCase):
         stdout, stderr = p.communicate()
         return stdout, stderr
 
-    def setUp(self):
-        cmd = (
-            'python generateDS.py --no-dates --no-versions -f '
-            '-o tests/out2_sup.py -s tests/out2_sub.py '
-            '--super=out2_sup -u gends_user_methods tests/people.xsd'
-        )
-        stdout, stderr = self.execute(cmd, cwd='..')
-        self.failUnlessEqual(len(stdout), 0)
-        self.failUnlessEqual(len(stderr), 0)
+##     def setUp(self):
+##         print 'running setUp'
+##         cmd = (
+##             'python generateDS.py --no-dates --no-versions -f '
+##             '-o tests/out2_sup.py -s tests/out2_sub.py '
+##             '--super=out2_sup -u gends_user_methods tests/people.xsd'
+##         )
+##         stdout, stderr = self.execute(cmd, cwd='..')
+##         self.failUnlessEqual(len(stdout), 0)
+##         self.failUnlessEqual(len(stderr), 0)
 
 ##     def tearDown(self):
 ##         for f in [ "out2_sub.py", "out2_sup.py" ]:
@@ -34,14 +35,20 @@ class GenTest(unittest.TestCase):
 ##                 pass
 
     def test_001_compare_superclasses(self):
+        cmd = (
+            'python generateDS.py --no-dates --no-versions -f '
+            '-o tests/out2_sup.py -s tests/out2_sub.py '
+            '--super=out2_sup -u gends_user_methods tests/people.xsd'
+        )
+        stdout, stderr = self.execute(cmd, cwd='..')
+        self.failUnlessEqual(len(stdout), 0)
+        self.failUnlessEqual(len(stderr), 0)
         cmd = 'diff out1_sup.py out2_sup.py'
         result, err = self.execute(cmd)
         #print 'len(result):', len(result)
         # Ignore the differing lines containing the date/time.
         #self.failUnless(len(result) < 130 and result.find('Generated') > -1)
         self.check_result(result, err, ())
-
-    def test_002_compare_subclasses(self):
         cmd = 'diff out1_sub.py out2_sub.py'
         result, err = self.execute(cmd)
         # Ignore the differing lines containing the date/time.
@@ -128,9 +135,9 @@ class GenTest(unittest.TestCase):
             'print (node.get_name(), node.get_valueOf_())"'
         )
         cmd = cmdTempl % (t_, t_)
-        print 'cmd:', cmd
+        #print 'cmd:', cmd
         result, err = self.execute(cmd)
-        print 'result: %s' % result
+        #print 'result: %s' % result
         self.failUnlessEqual(result, """\
 ('child1', 'value1')
 """)
@@ -453,6 +460,41 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
+    def test_021_anonymous_type(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'anonymous_type'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+    def test_022_one_per(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '--one-file-per-xsd --output-directory="tests/OnePer" '
+            '--module-suffix="One" '
+            '--super=%s2_sup '
+            'tests/%s00.xsd'
+        )
+        t_ = 'oneper'
+        cmd = cmdTempl % (t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff OnePer/%sType00_1One.py OnePer/%sType00_2One.py' % (
+            t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+
     def check_result(self, result, err, ignore_strings):
         self.failUnlessEqual(len(result), 0)
         self.failUnlessEqual(len(err), 0)
@@ -479,7 +521,7 @@ class GenTest(unittest.TestCase):
 def suite():
     # The following is obsolete.  See Lib/unittest.py.
     #return unittest.makeSuite(GenTest)
-    loader = unittest.TestLoader()
+    loader = unittest.defaultTestLoader
     testsuite = loader.loadTestsFromTestCase(GenTest)
     return testsuite
 
